define((function () { 'use strict';

	const hs = document.documentElement.style;

	{
		hs.color = "#222";
	}

}));
